import argparse, json, os

default_dict = {
    "opt_numConfs": 5,
    "opt_numThreads": 0,
    "opt_maxIters": 1500,
    "drawing_subImgSize_edge": 250,
    "drawing_default": "polymer.png",
    "MV_gridSpacing": 0.2,
    "MV_boxMargin": 2.0,
    "plot_dataPoint": "o",
    "plot_Filename": "Size-dependent-stats.png"
}


def readJson(filepath):
    with open(filepath, "r") as S: #this is where many defaults are set so they can easily be changed.
        settings_dict = json.load(S)
    return settings_dict


def getArgs():
    parser = argparse.ArgumentParser()
    parser.add_argument('-s', '--show', default = False, action = "store_true", help = "prints all settings")
    parser.add_argument('-w', '--write', default = False, action = "store_true", help = "writes a copy of settings.json to cwd for user to edit manually.")
    args = parser.parse_args()
    return args


def writeJson(dict, path):
    json_object = json.dumps(dict, indent=4)
    with open(path, "w") as outfile:
        outfile.write(json_object)


def main():
    args = getArgs()
    settingsFile = "HXSettings.json"
    if args.show:
        if os.path.exists(settingsFile):
            print("All hydrophobicity_explorer packages will use these user-defined settings in HXSettings.json")
            user_settings = readJson(settingsFile)
            print(user_settings)
        else:
            print(default_dict)
    if args.write:
        writeJson(default_dict, settingsFile)


if __name__ == "__main__":
    main()



import rdkit, argparse
from rdkit import Chem
from rdkit.Chem import AllChem
from hydrophobicity_explorer.MakePolymer import optPol, getStaticSettings, write_pol, Polymer

def getArgs():
    parser = argparse.ArgumentParser()
    parser.add_argument("-s", "--smiles", type=str, help="Complete smiles string to be converted.")
    parser.add_argument("-m", "--smarts", type=str, help="Complete smarts string to be converted.")
    parser.add_argument("-i", "--inchi", type=str, help="Complete inchi string to be converted.")
    parser.add_argument("-f", "--file", type=str, help="Filename you would like to save to. MOL, PDB and XYZ are acceptable.")
    args = parser.parse_args()
    return args

def main():
    args = getArgs()
    defaults = getStaticSettings()

    VARS = vars(args)
    given_args = {k: v for (k, v) in VARS.items() if v is not None}

    if len(given_args) > 2 and args.file is not None:
        print("Please only provide one input molecule type.")
        quit()

    if args.file is None:
        print("please provide a filename with the -f flag.")
        quit()

    if args.smiles is not None:
        mol = Chem.MolFromSmiles(args.smiles)
    elif args.smarts is not None:
        mol = Chem.MolFromSmarts(args.smarts)
    elif args.inchi is not None:
        mol = Chem.MolFromInchi(args.inchi)
    else:
        print("I am confused. Input format not recognized.")
        quit()

    POL = Polymer(smiles=Chem.MolToSmiles(mol))
    #doing this extra step so opt is consistent with option used in primary script. Only need to change one set of parameters while finding best options.
    POL.suppl = optPol(
        POL.flat,
        nConfs=defaults["opt_numConfs"],
        threads=defaults["opt_numThreads"],
        iters=defaults["opt_maxIters"])  #this function also saves the file.

    write_pol(args.file, suppl=POL.suppl, verbosity=True)

if __name__ == "__main__":
    main()



import setuptools

setuptools.setup(
    name="hydrophobicity_explorer",
    version="0.1.3.4",
    url="https://github.com/TheHydrophobicityProject/HydrophobicityExplorer",
    author="Sander Cohen-Janes",
    author_email="sander.cohen-janes@yale.edu",
    description="Facilitates solubility calculations on a wide range of polymers.",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    install_requires=["rdkit", "scipy", "pandas", "matplotlib"],
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6'
    ],
    entry_points={
        'console_scripts': [ #this section allows us to use functions from the command line.
            # 'command = package.module:function',
            'makePol = hydrophobicity_explorer.MakePolymer:main',
            'customPol = hydrophobicity_explorer.custom_input_to_mol_file:main',
            'HXSettings = hydrophobicity_explorer.settings:main',
            'HXNB = hydrophobicity_explorer.nb:main',
            'HXLib = hydrophobicity_explorer.smiles:main'
        ],
    },
)
